@@ -6,6 +6,21 @@ from polyapi.utils import add_import_to_init, init_the_init
 from polyapi.typedefs import TableSpecDto
 from polyapi.constants import JSONSCHEMA_TO_PYTHON_TYPE_MAP
 
+def scrub(data) -> Dict[str, Any]:
+    if (not data or not isinstance(data, (Dict, List))): return data
+    if isinstance(data, List):
+        return [scrub(item) for item in data]
+    else:
+        temp = {}
+        secrets = ["x_api_key", "x-api-key", "access_token", "access-token", "authorization", "api_key", "api-key", "apikey", "accesstoken", "token", "password", "key"]
+        for key, value in data.items():
+            if isinstance(value, (Dict, List)):
+                temp[key] = scrub(data[key])
+            elif key.lower() in secrets:
+                temp[key] = '********'
+            else:
+                temp[key] = data[key]
+        return temp
 
 def scrub_keys(e: Exception) -> Dict[str, Any]:
     """
@@ -16,7 +31,7 @@ def scrub_keys(e: Exception) -> Dict[str, Any]:
         "error": str(e),
         "type": type(e).__name__,
         "message": str(e),
-        "args": getattr(e, 'args', None)
+        "args": scrub(getattr(e, 'args', None))
     }
 
 
@@ -40,6 +55,10 @@ def first_result(rsp):
         return rsp['results'][0] if rsp['results'] else None
     return rsp
 
+def delete_one_response(rsp):
+    if isinstance(rsp, dict) and isinstance(rsp.get('deleted'), int):
+        return { 'deleted': bool(rsp.get('deleted')) }
+    return { 'deleted': false }
 
 _key_transform_map = {
     "not_": "not",
@@ -286,6 +305,30 @@ class {table_name}:{table_description}
             query = kwargs
         return execute_query({table_name}.table_id, "update", transform_query(query))
 
+    @overload
+    @staticmethod
+    def update_one(id: str, query: {table_name}UpdateManyQuery) -> {table_name}Row: ...
+    @overload
+    @staticmethod
+    def update_one(*, id: str, where: Optional[{table_name}WhereFilter], data: {table_name}Subset) -> {table_name}Row: ...
+
+    @staticmethod
+    def update_one(*args, **kwargs) -> {table_name}Row:
+        if args:
+            if len(args) != 2 or not isinstance(args[0], str) or not isinstance(args[1], dict):
+                raise TypeError("Expected id and query as arguments or as kwargs")
+            query = args[1]
+            if not isinstance(query["where"], dict):
+                query["where"] = {{}}
+            query["where"]["id"] = args[0]
+        else:
+            query = kwargs
+            if not isinstance(query["where"], dict):
+                query["where"] = {{}}
+            query["where"]["id"] = kwargs["id"]
+            query.pop("id", None)
+        return first_result(execute_query({table_name}.table_id, "update", transform_query(query)))
+
     @overload
     @staticmethod
     def delete_many(query: {table_name}DeleteQuery) -> PolyDeleteResults: ...
@@ -301,7 +344,31 @@ class {table_name}:{table_description}
             query = args[0]
         else:
             query = kwargs
-        return execute_query({table_name}.table_id, "delete", query)
+        return execute_query({table_name}.table_id, "delete", transform_query(query))
+
+    @overload
+    @staticmethod
+    def delete_one(query: {table_name}DeleteQuery) -> PolyDeleteResult: ...
+    @overload
+    @staticmethod
+    def delete_one(*, where: Optional[{table_name}WhereFilter]) -> PolyDeleteResult: ...
+
+    @staticmethod
+    def delete_one(*args, **kwargs) -> PolyDeleteResult:
+        if args:
+            if len(args) != 2 or not isinstance(args[0], str) or not isinstance(args[1], dict):
+                raise TypeError("Expected id and query as arguments or as kwargs")
+            query = args[1]
+            if not isinstance(query["where"], dict):
+                query["where"] = {{}}
+            query["where"]["id"] = args[0]
+        else:
+            query = kwargs
+            if not isinstance(query["where"], dict):
+                query["where"] = {{}}
+            query["where"]["id"] = kwargs["id"]
+            query.pop("id", None)
+        return delete_one_response(execute_query({table_name}.table_id, "delete", transform_query(query)))
 '''
 
 
